
Configuration options
=====================

Networking-odl uses the following configuration options
in the Neutron server configuration, which is typically
`/etc/neutron/neutron.conf`.

.. show-options::

    ml2_odl
